==> seedsui-react-5.8.10.tgz: package/lib/DatePicker/RangeCombo/index.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
var _excluded = ["rangeLimit", "format", "titles", "ranges"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef } from 'react';
import defaultRanges from "./../RangeMain/defaultRanges";
import getRangeDisplayValue from "./getRangeDisplayValue";
import Combo from "./../../Select/Combo";
// 测试使用
// import Combo from 'seedsui-react/lib/Select/Combo'
import Modal from "./../RangeModal";

// 日期区间
var RangeCombo = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var rangeLimit = _ref.rangeLimit,
    format = _ref.format,
    titles = _ref.titles,
    _ref$ranges = _ref.ranges,
    ranges = _ref$ranges === void 0 ? defaultRanges : _ref$ranges,
    props = _objectWithoutProperties(_ref, _excluded);
  // 扩展非标准属性
  if (!props.ModalProps) {
    props.ModalProps = {};
  }

  // 标题透传
  if (titles) {
    props.ModalProps.titles = titles;
  }

  // 限制透传
  if (rangeLimit) {
    props.ModalProps.rangeLimit = rangeLimit;
  }
  return /*#__PURE__*/React.createElement(Combo, _extends({
    ref: ref,
    ModalComponent: Modal,
    ranges: ranges,
    displayValueFormatter: function displayValueFormatter(params) {
      var _ref$current, _ref$current$getActiv;
      var activeKey = ref === null || ref === void 0 || (_ref$current = ref.current) === null || _ref$current === void 0 || (_ref$current$getActiv = _ref$current.getActiveKey) === null || _ref$current$getActiv === void 0 ? void 0 : _ref$current$getActiv.call(_ref$current);

      // 根据日期区间计算显示标签，如果有重复选项，将优先取记录的选中项
      var displayValue = getRangeDisplayValue(_objectSpread({
        format: format,
        currentActiveKey: activeKey
      }, params));
      return displayValue;
    }
  }, props));
});
export default RangeCombo;

==> seedsui-react-5.8.25.tgz: package/lib/DatePicker/RangeCombo/index.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
var _excluded = ["format", "customModal", "titles", "ranges"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef } from 'react';
import defaultRanges from "./../RangeMain/SelectorMain/defaultRanges";
import getRangeDisplayValue from "./getRangeDisplayValue";
import Combo from "./../../Select/Combo";
// 测试使用
// import Combo from 'seedsui-react/lib/Select/Combo'
import Modal from "./../RangeModal";

// 日期区间
var RangeCombo = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var format = _ref.format,
    customModal = _ref.customModal,
    titles = _ref.titles,
    _ref$ranges = _ref.ranges,
    ranges = _ref$ranges === void 0 ? defaultRanges : _ref$ranges,
    props = _objectWithoutProperties(_ref, _excluded);
  // 扩展非标准属性
  if (!props.ModalProps) {
    props.ModalProps = {};
  }

  // 标题透传
  if (titles) {
    props.ModalProps.titles = titles;
  }
  if (customModal) {
    props.ModalProps.customModal = customModal;
  }
  return /*#__PURE__*/React.createElement(Combo, _extends({
    ref: ref,
    ModalComponent: Modal,
    ranges: ranges,
    displayValueFormatter: function displayValueFormatter(params) {
      var _ref$current, _ref$current$getActiv;
      var activeKey = ref === null || ref === void 0 || (_ref$current = ref.current) === null || _ref$current === void 0 || (_ref$current$getActiv = _ref$current.getActiveKey) === null || _ref$current$getActiv === void 0 ? void 0 : _ref$current$getActiv.call(_ref$current);

      // 根据日期区间计算显示标签，如果有重复选项，将优先取记录的选中项
      var displayValue = getRangeDisplayValue(_objectSpread({
        format: format,
        currentActiveKey: activeKey
      }, params));
      return displayValue;
    }
  }, props));
});
export default RangeCombo;
